@@ -26,7 +26,7 @@ def raw_jsontemplate(filename):
         The template filename relative to the templates directory.
     """
 
-    cfg = Tipfy.app.get_config('tipfy.ext.jsontemplates')
+    cfg = Tipfy.app.get_config('tipfy.ext.jsontemplate')
     path = os.path.join(cfg["templates_dir"], filename)
     return open(path).read()
 
